Glossary
========

.. glossary::

    assay
        A collection of samples measured in experimental conditions.

    aggregated descriptor
        A value obtained from aggregating the value of a descriptor using all features in a group.
        e.g. the feature group `m/z` is the average value of all features `m/z` in the group.

    consensus annotation
        the process of combining the annotation of features in a group into a single annotation

    DBSCAN
        Density-based spatial clustering of applications with noise.

    data matrix
        A table containing extracted data from chemical species in wide format, i.e., each
        row of the matrix is associated with a sample and each column is associated with
        a feature group

    envelope
        A collection of isotopologues features.

    EIC
        Extracted Ion Chromatograms

    feature
        A ROI subregion associated with a chemical species in a sample

    feature descriptor
        A numeric property that describes a feature. For example, peak area or peak width.

    feature group
        A collection of features detected in different samples associated with the same chemical identity.

    feature matching
        An algorithm that assigns a feature group to features based on their chemical identity.

    LC-MS
        Liquid Chromatography coupled to Mass spectrometry.

    m/z
        Mass to charge ratio

    ROI
        Region of Interest. A region extracted from a raw data file which may contain features.

    Rt
        The retention time of a chromatographic peak

    sample
        And individual experimental measurement

    sample group
        a label that group samples by a subject characteristic. e.g. healthy, disease, etc...

    sample type
        a label that groups samples by a sample characteristic. e.g. subject, QA, blank, etc...
        
    SNR
        signal-to-noise ratio
        
    